Package: eyeris
Type: Package
Title: Flexible, Extensible, & Reproducible Pupillometry Preprocessing
Version: 2.1.1
Date: 2025-07-25
Authors@R: 
  c(
    person(given = "Shawn", family = "Schwartz", role = c("aut", "cre"), 
           email = "shawn.t.schwartz@gmail.com",
           comment = c(ORCID = "0000-0001-6444-8451")),
    person(given = "Mingjian", family = "He", role = "ctb"),
    person(given = "Haopei", family = "Yang", role = "ctb"),
    person(given = "Alice", family = "Xue", role = "ctb"),
    person(given = "Gustavo", family = "Santiago-Reyes", role = "ctb")
  )
Description: Pupillometry offers a non-invasive window into the mind and has been used extensively as a psychophysiological readout of arousal signals linked with cognitive processes like attention, stress, and emotional states [Clewett et al. (2020) <doi:10.1038/s41467-020-17851-9>; Kret & Sjak-Shie (2018) <doi:10.3758/s13428-018-1075-y>; Strauch (2024) <doi:10.1016/j.tins.2024.06.002>]. Yet, despite decades of pupillometry research, many established packages and workflows to date lack design patterns based on Findability, Accessibility, Interoperability, and Reusability (FAIR) principles [see Wilkinson et al. (2016) <doi:10.1038/sdata.2016.18>]. 'eyeris' provides a modular, performant, and extensible preprocessing framework for pupillometry data with BIDS-like organization and interactive output reports [Esteban et al. (2019) <doi:10.1038/s41592-018-0235-4>; Gorgolewski et al. (2016) <doi:10.1038/sdata.2016.44>]. Development was supported, in part, by the Stanford Wu Tsai Human Performance Alliance, Stanford Ric Weiland Graduate Fellowship, Stanford Center for Mind, Brain, Computation and Technology, NIH National Institute on Aging Grants (R01-AG065255, R01-AG079345), NSF GRFP (DGE-2146755), McKnight Brain Research Foundation Clinical Translational Research Scholarship in Cognitive Aging and Age-Related Memory Loss, American Brain Foundation, and the American Academy of Neurology.
Encoding: UTF-8
Depends: R (>= 4.1)
Imports: eyelinker, dplyr, gsignal, purrr, zoo, cli, rlang, stringr,
        utils, stats, graphics, grDevices, tidyr, progress, data.table,
        withr, lifecycle, MASS, viridis, fields, jsonlite, rmarkdown
RoxygenNote: 7.3.2
Suggests: knitr, testthat (>= 3.0.0), devtools
VignetteBuilder: knitr
License: MIT + file LICENSE
Config/testthat/edition: 3
URL: https://shawnschwartz.com/eyeris/,
        https://github.com/shawntz/eyeris/
BugReports: https://github.com/shawntz/eyeris/issues
NeedsCompilation: no
Packaged: 2025-07-26 05:29:18 UTC; shawn
Author: Shawn Schwartz [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6444-8451>),
  Mingjian He [ctb],
  Haopei Yang [ctb],
  Alice Xue [ctb],
  Gustavo Santiago-Reyes [ctb]
Maintainer: Shawn Schwartz <shawn.t.schwartz@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-26 16:10:02 UTC
Built: R 4.3.3; ; 2025-07-26 18:53:24 UTC; unix
