# Generated by roxygen2: do not edit by hand

S3method(plot,eyeris)
export(bidsify)
export(bin)
export(deblink)
export(detransient)
export(detrend)
export(downsample)
export(epoch)
export(eyelink_asc_binocular_demo_dataset)
export(eyelink_asc_demo_dataset)
export(eyelogger)
export(eyeris_color_palette)
export(glassbox)
export(interpolate)
export(load_asc)
export(lpfilt)
export(pipeline_handler)
export(plot_binocular_correlation)
export(plot_gaze_heatmap)
export(summarize_confounds)
export(zscore)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(grDevices,dev.off)
importFrom(grDevices,jpeg)
importFrom(grDevices,png)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,hist)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(lifecycle,is_present)
importFrom(rlang,":=")
importFrom(stats,cor)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(utils,modifyList)
importFrom(utils,write.csv)
importFrom(withr,with_seed)
